#!/bin/perl -w
#******************************************************************************
#                                                                             *
#                                LayGO (tm)                                   *
#           Copyright (c) 1998-2000 by Advanced Relay Corporation             *
#                           All rights reserved.                              *
#                                                                             *
#******************************************************************************
#
#    LayGO for Perl5 installation script.
#
#    Syntax: perl laygopl.pl [install | uninstall]
#
#******************************************************************************

use strict;
use Config;
use File::Spec;
use File::Path;
use File::Copy;

#******************************************************************************
#                                    Main Line                                *
#******************************************************************************

MainLine();

#******************************************************************************
#                                   Subroutines                               *
#******************************************************************************

sub MainLine
{
	my $syntax		= "Syntax: perl $0 [ install | uninstall ]";
	my $osname		= $Config{'osname'};
	my $installdir	= $Config{'installsitelib'};
	my $dlext		= $Config{'dlext'};
	my $base		= 'Laygo';

	my $packagefile	= "$base.pm";
	my $packagedir	= $installdir;
	my $packagepm	= File::Spec->catfile($packagedir, $packagefile);

	my @autofiles	= ('bs', $dlext);
	my $autodir		= File::Spec->catfile($packagedir, "auto", $base);

	my @layerfiles	= ('FrmRelay', 'Lapb', 'Lapd', 'X21bis', 'X25');
	my $layerdir	= File::Spec->catfile($packagedir, $base);

	my $sourcedir	= undef;

	#
	#  Make OS dependent adjustments
	#
	if ($osname =~ /Win/)
	{
		@autofiles = (@autofiles, 'exp', 'lib');
		$sourcedir = 'win32';
	}
	elsif ($osname eq 'linux' || $osname eq 'solaris')
	{
		$sourcedir = $osname;
	}

	#
	#  Adjust file lists
	#
	for (my $i = 0; $i < @layerfiles; $i++)
	{
		$layerfiles[$i] .= '.pm';
	}

	for (my $i = 0; $i < @autofiles; $i++)
	{
		$autofiles[$i] = File::Spec->catfile($sourcedir, $base . '.' . $autofiles[$i]);
	}

	#
	#  Do the task or give an error
	#
	if ($#ARGV != 0)
	{
		print $syntax;
	}
	elsif (!defined $sourcedir)
	{
		print "Error: $base package not implemented for '$osname'.\n";
	}
	elsif (!-e $sourcedir)
	{
		print "Error: $base package not found for '$osname'.\n";
	}
	elsif (!-e $installdir)
	{
		print "Error: Perl site library directory '$installdir' not found.\n";
	}
	else
	{
		my $task = $ARGV[0];

		if ($task eq 'install')
		{
			print "Installing $base package to $installdir:\n";

			MakeDirectory($layerdir);
			MakeDirectory($autodir);

			CopyFile ($packagefile, $packagedir);
			CopyFiles(\@layerfiles, $layerdir);
			CopyFiles(\@autofiles,  $autodir);

			print "Install completed successfully.\n";
		}
		elsif ($task eq 'uninstall')
		{
			print "Uninstalling $base package from $installdir:\n";

			RemoveFiles($packagepm);
			RemoveFiles($layerdir);
			RemoveFiles($autodir);

			print "Uninstall completed successfully.\n";
		}
		else
		{
			print $syntax;
		}
	}
}

sub MakeDirectory
{
	my $dir = shift;

	if (!-e $dir)
	{
		mkpath($dir, 1, 0755) || die "Error: Cannot create '$dir'.\n";
	}
}

sub CopyFile
{
	my ($file, $dir) = @_;

	copy($file, $dir) || die "Error: Cannot copy '$file' to '$dir'.\n";
}

sub CopyFiles
{
	my ($filelist, $dir) = @_;

    foreach my $file (@$filelist)
    {
		CopyFile($file, $dir);
    }
}

sub RemoveFiles
{
	my $file = shift;

	if (-e $file)
	{
		rmtree($file, 1, 1) || die "Error: Cannot remove '$file'.\n";
	}
}

1;

#******************************************************************************
#                                   End of File                               *
#******************************************************************************
