#!/bin/perl -w
#******************************************************************************
#                                                                             *
#                                LayGO (tm)                                   *
#           Copyright (c) 1998-2000 by Advanced Relay Corporation             *
#                           All rights reserved.                              *
#                                                                             *
#******************************************************************************
#
#  $Source: q:/laygorcs/hex.pl $
#
#      $Id: hex.pl 1.1 2000/02/29 17:51:47 tiktin Release $
#
#  MODULE DESCRIPTION
#
#    Exports hex formatting and binary conversion routines.
#
#******************************************************************************

use strict;
use Laygo;
use Config;
use POSIX "isprint";

my $BIGENDIAN = $Config{'byteorder'} == 4321 ? 1 : 0;

sub hexDump
{
	my ($buffer, $size) = @_;

	print &hexFormat($buffer, $size, 16);
}

sub hexFormat
{
	my ($buffer, $size, $width) = @_;
	my $s = "";
	my $i;
	my $j;
	my $b;

	$i = 0;

	while ($i < $size)
	{
		$j = $i;
		while ($j < $size && $j < $i + $width)
		{
			$s .= sprintf(" %02X", lgo_BufferGet($buffer, $j));
			$j++;
		}

		while ($j < $i + $width)
		{
			$s .= "   ";
			$j++;
		}

		$s .= " # ";

		$j = $i;
		while ($j < $size && $j < $i + $width)
		{
			$b = lgo_BufferGet($buffer, $j);
			if (isprint(chr($b)))
			{
				$s .= chr($b);
			}
			else
			{
				$s .= ".";
			}
			$j++;
		}

		$s .= "\n";
		$i += $width;
	}

	return $s;
}

sub hexFill
{
	my ($buffer, $index, $max, $forward) = @_;
	my $i;

	if ($forward)
	{
		for ($i = 0; $index < $max; $i++, $index++)
		{
			lgo_BufferSet($buffer, $index, 65 + ($i % 26));
		}
	}
	else
	{
		for ($i = 0; $index < $max; $i++, $index++)
		{
			lgo_BufferSet($buffer, $index, 90 - ($i % 26));
		}
	}
}

sub hexGetLong
{
	my ($buffer, $i) = @_;
	my $long;

	if ($BIGENDIAN)
	{
	 	$long = lgo_BufferGet($buffer, $i + 3)			|
			   (lgo_BufferGet($buffer, $i + 2) <<  8)	|
			   (lgo_BufferGet($buffer, $i + 1) << 16)	|
			   (lgo_BufferGet($buffer, $i + 0) << 24);
	}
	else
	{
	 	$long = lgo_BufferGet($buffer, $i + 0)			|
			   (lgo_BufferGet($buffer, $i + 1) <<  8)	|
			   (lgo_BufferGet($buffer, $i + 2) << 16)	|
			   (lgo_BufferGet($buffer, $i + 3) << 24);
	}
	return $long;
}

sub hexGetShort
{
	my ($buffer, $i) = @_;
	my $short;

	if ($BIGENDIAN)
	{
	 	$short = lgo_BufferGet($buffer, $i + 1)			|
			    (lgo_BufferGet($buffer, $i + 0) <<  8);
	}
	else
	{
	 	$short = lgo_BufferGet($buffer, $i + 0)			|
			    (lgo_BufferGet($buffer, $i + 1) <<  8);
	}
	return $short;
}

1;

#******************************************************************************
#                                   End of File                               *
#******************************************************************************
