#!/bin/perl -w
#******************************************************************************
#                                                                             *
#                                LayGO (tm)                                   *
#           Copyright (c) 1998-2000 by Advanced Relay Corporation             *
#                           All rights reserved.                              *
#                                                                             *
#******************************************************************************
#
#  $Source: q:/laygorcs/tdat.pl $
#
#      $Id: tdat.pl 1.1 2000/02/29 17:51:48 tiktin Release $
#
#  MODULE DESCRIPTION
#
#    Exports test data frame handling routines.
#
#******************************************************************************

use strict;
use Laygo;

my @TDAT = ();

sub tdatLoad
{
	my @tdat = &tdatLoadFile(shift());

	if (@tdat)
	{
		if (@TDAT)
		{
			my $i;

			for ($i = 0; $i <= $#TDAT; $i++)
			{
				lgo_BufferFree(&tdatGetFrame($i));
			}
		}
		@TDAT = @tdat;

		return &tdatGetCount();
	}

	return 0;
}

sub tdatGet
{
	my ($i, $s) = @_;

	if (@TDAT && $i <= $#TDAT)
	{
		return $TDAT[$i]->{$s};
	}

	return;
}

sub tdatGetCount
{
	return (@TDAT ? $#TDAT + 1 : 0);
}

sub tdatGetLabel
{
	return &tdatGet(shift(), 'label');
}

sub tdatGetSize
{
	return &tdatGet(shift(), 'size');
}

sub tdatGetFlag
{
	return &tdatGet(shift(), 'flag');
}

sub tdatGetFrame
{
	return &tdatGet(shift(), 'frame');
}

sub tdatListData
{
	my $s = "";
	my $i;

	if (@TDAT)
	{
		for ($i = 0; $i <= $#TDAT; $i++)
		{
			$s = $s . "\t" . $TDAT[$i]->{'label'};
		}
	}

	return $s;
}

sub tdatLoadFile
{
	my $file	= shift();
	my @tdat	= ();
	my @frame	= ();
	my $count	= 0;
	my $next	= 0;
	my $label;
	my $flag;
	my $s;
	my $f;
	my $i;
	local(*TDAT);

	if (open(TDAT, "< $file"))
	{
		while (defined ($s = <TDAT>))
		{
			chop($s);

			if ($s =~ m/^\#/)
			{
				# Comment
			}
			elsif ($s =~ m/^\]/)
			{
				# EOF
				last;
			}
			elsif ($s =~ m/^\[\s*([^\#]+)\s*\]/)
			{
				if ($count > 0)
				{
					$f = lgo_BufferNew($#frame + 1);

					for ($i = 0; $i <= $#frame; $i++)
					{
						lgo_BufferSet($f, $i, $frame[$i]);
					}

					$tdat[$count-1] = { 'label' => $label, 'frame' => $f, 'size' => $#frame + 1, 'flag' => $flag };
					@frame = ();
				}

				$count++;
				$next	= 0;
				$label	= $1;
				$flag	=  0;

				if ($label =~ m/([^\{]+)\s*\{\s*(.+)\s*\}/)
				{
					$label	= $1;
					$flag	= $2;
				}

				$label =~ s/\s*$//;
				$label =~ s/\t/ /;
			}
			elsif ($s =~ m/([^\#]+)/)
			{
				my @bytes = split(/\s/, $1);
				my $b;
				my $i;

				foreach $b (@bytes)
				{
					if ($b =~ m/^\"(.+)\"$/)
					{
						for ($i = 0; $i < length $1; $i++)
						{
							$frame[$next++] = ord(substr $1,$i,1);
						}
					}
					elsif ($b =~ m/^0?[Xx]?0?([0-9A-Fa-f]+)$/)
					{
						$frame[$next++] = hex($1);
					}
					elsif ($b =~ m/^0%([01]+)$/)
					{
						my $v = 0;

						for ($i = 0; $i < length $1; $i++)
						{
							$v <<= 1;
							if (ord(substr $1,$i,1))
							{
								$v++;
							}
						}
						$frame[$next++] = $v;
					}
					else
					{
						print STDERR "File format error '$b'\n";
					}
				}
			}
		}

		close TDAT;

		if ($count > 0)
		{
			$f = lgo_BufferNew($#frame + 1);

			for ($i = 0; $i <= $#frame; $i++)
			{
				lgo_BufferSet($f, $i, $frame[$i]);
			}

			$tdat[$count-1] = { 'label' => $label, 'frame' => $f, 'size' => $#frame + 1, 'flag' => $flag };
		}
	}

	return @tdat;
}

1;

#******************************************************************************
#                                   End of File                               *
#******************************************************************************
